CapsuleContainer class

Contains the data of Capsules. See the documentation for more.

Implemented types
Implementers
Available extensions

Constructors

CapsuleContainer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes any resources associated with this object.
override
listen(CapsuleListener listener) → void Function()
Temporarily listens to changes in a given set of Capsules.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onNextUpdate<T>(Capsule<T> capsule, void callback()) → void Function()
Runs the supplied callback the next time capsule is updated or disposed.
read<T>(Capsule<T> capsule) → T
Reads the current data of the supplied Capsule, initializing it if needed.
runTransaction(void sideEffectTransaction()) → void
Runs the supplied sideEffectTransaction that combines all side effect state updates into a single container rebuild sweep. These state updates can originate from the same or different capsules, enabling you to make transactional side effect changes across capsules.
toString() → String
A string representation of this object.
inherited
warmUp<T>(Iterable<Capsule<AsyncValue<T>>> capsules) → Future<void>

Available on CapsuleContainer, provided by the WarmUpCapsuleContainer extension

Warms up the specified capsules by waiting for them to all be AsyncData.

Operators

operator ==(Object other) → bool
The equality operator.
inherited